@@ -4,7 +4,7 @@
 #
 #       AUTHOR:  Aliaksandr P. Zahatski, <zahatski@gmail.com>
 #===============================================================================
-#$Id: ListLevels.pm 574 2009-07-13 03:57:29Z zag $
+#$Id$
 package T::Parser::ListLevels;
 use strict;
 use warnings;
@@ -28,7 +28,7 @@ q#<pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><itemlist
     );
 }
 
-sub t2_two_interrupted_items_blocks : Test(2) {
+sub t2_two_interrupted_items_blocks : Test {
     my $t = shift;
     my $x = $t->parse_to_xml( <<T1, 'Perl6::Pod::Parser::ListLevels' );
 =begin pod
@@ -39,16 +39,13 @@ sub t2_two_interrupted_items_blocks : Test(2) {
 =item a2
 =end pod
 T1
-    $t->is_deeply_xml(
-        $x,
+$t->is_deeply_xml ($x,
 q#<pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><itemlist pod:type='block' pod:listtype='unordered'><item pod:type='block'>i1
 </item><item pod:type='block'>i2
 </item></itemlist><head1 pod:type='block'>test
 </head1><itemlist pod:type='block' pod:listtype='unordered'><item pod:type='block'>a1
 </item><item pod:type='block'>a2
-</item></itemlist></pod>
-#
-      )
+</item></itemlist></pod>#)
 
 }
 
@@ -60,17 +57,15 @@ sub t3_list_type_ordered : Test(1) {
 entry1
 =for item :numbered
 entry2
-
-Test messase
 =end pod
 T1
+
     $t->is_deeply_xml(
         $x,
         q#
 <pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><itemlist pod:type='block' pod:listtype='ordered'><item pod:type='block' numbered='1'>entry1
 </item><item pod:type='block' numbered='1'>entry2
-</item></itemlist>Test messase
-</pod>#
+</item></itemlist></pod>#
     );
 }
 
@@ -110,11 +105,31 @@ q#<pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><para pod:
     );
 }
 
-sub t6_docbook : Test(1) {
+sub t06_test_formatting_codes_in_lists : Test {
+    my $t = shift;
+    my $x = $t->parse_to_xml( <<T1, 'Perl6::Pod::Parser::ListLevels' );
+=begin pod
+=for item term:<TE>
+sds L<dsd>
+=for item term:<TT>
+* sd sds
+=head1 sd
+=end pod
+T1
+    $t->is_deeply_xml(
+        $x,
+q#<pod pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'><itemlist pod:type='block' pod:listtype='unordered'><item pod:type='block'>sds <L pod:section='' pod:type='code' pod:scheme='' pod:is_external='' pod:name='' pod:address=''>dsd</L>
+</item><item pod:type='block'>* sd sds
+</item></itemlist><head1 pod:type='block'>sd
+</head1></pod>#);
+}
+
+sub t6_docbook : Test {
     my $t = shift;
     my $x = $t->parse_to_xml( <<T1, 'Perl6::Pod::Parser::ListLevels' );
 T1
+
+    "last";
 }
 1;
 
-
